==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority.md <==
# AwsCertificateManagerCertificateAuthority


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')
```



| Illustration | AwsCertificateManagerCertificateAuthority | AwsCertificateManagerCertificateAuthorityCard | AwsCertificateManagerCertificateAuthorityGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority.png) | ![illustration for AwsCertificateManagerCertificateAuthority](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority.Local.png) | ![illustration for AwsCertificateManagerCertificateAuthorityCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthorityCard.Local.png) | ![illustration for AwsCertificateManagerCertificateAuthorityGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthorityGroup.Local.png) |




## AwsCertificateManagerCertificateAuthority

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthority
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthority('AwsCertificateManagerCertificateAuthority', 'Aws Certificate Manager Certificate Authority', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthority
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthority('AwsCertificateManagerCertificateAuthority', 'Aws Certificate Manager Certificate Authority', 'an optional tech label')
@enduml
```

## AwsCertificateManagerCertificateAuthorityCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityCard('AwsCertificateManagerCertificateAuthorityCard', 'Aws Certificate Manager Certificate Authority Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityCard('AwsCertificateManagerCertificateAuthorityCard', 'Aws Certificate Manager Certificate Authority Card', 'an optional description')
@enduml
```

## AwsCertificateManagerCertificateAuthorityGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityGroup('AwsCertificateManagerCertificateAuthorityGroup', 'Aws Certificate Manager Certificate Authority Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityGroup('AwsCertificateManagerCertificateAuthorityGroup', 'Aws Certificate Manager Certificate Authority Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority.md <==
# AwsCertificateManagerCertificateAuthority


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')
```



| Illustration | AwsCertificateManagerCertificateAuthority | AwsCertificateManagerCertificateAuthorityCard | AwsCertificateManagerCertificateAuthorityGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority.png) | ![illustration for AwsCertificateManagerCertificateAuthority](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority.Local.png) | ![illustration for AwsCertificateManagerCertificateAuthorityCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthorityCard.Local.png) | ![illustration for AwsCertificateManagerCertificateAuthorityGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthorityGroup.Local.png) |




## AwsCertificateManagerCertificateAuthority

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthority
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthority('AwsCertificateManagerCertificateAuthority', 'Aws Certificate Manager Certificate Authority', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthority
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthority('AwsCertificateManagerCertificateAuthority', 'Aws Certificate Manager Certificate Authority', 'an optional tech label')
@enduml
```

## AwsCertificateManagerCertificateAuthorityCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityCard('AwsCertificateManagerCertificateAuthorityCard', 'Aws Certificate Manager Certificate Authority Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityCard('AwsCertificateManagerCertificateAuthorityCard', 'Aws Certificate Manager Certificate Authority Card', 'an optional description')
@enduml
```

## AwsCertificateManagerCertificateAuthorityGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityGroup('AwsCertificateManagerCertificateAuthorityGroup', 'Aws Certificate Manager Certificate Authority Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsCertificateManagerCertificateAuthorityGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsCertificateManagerCertificateAuthority')

' renders the element
AwsCertificateManagerCertificateAuthorityGroup('AwsCertificateManagerCertificateAuthorityGroup', 'Aws Certificate Manager Certificate Authority Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
